@@ -1,9 +1,9 @@
 use core::panic;
-use std::{ str::FromStr};
 use pest::Parser;
 use proc_macro::TokenStream;
+use std::str::FromStr;
 
-use super::component_scan::attr_split_to_map;
+use super::scan_path_utils::attr_split_to_map;
 
 #[derive(Debug, Clone)]
 pub struct FunContent {
@@ -27,15 +27,9 @@ pub fn read_this_parset(unparsed_file: String) -> Option<FunContent> {
             Rule::scan_macro_fun_content => {
                 let mut inner_rules = line.into_inner();
                 let fun_name_group = inner_rules.next().unwrap().as_str().to_string();
-                println!("fun_name_group:{:?}", fun_name_group);
-
                 let fun_brackets_group = inner_rules.next().unwrap().as_str().to_string();
-                println!("fun_brackets_group:{:?}", fun_brackets_group);
-
                 let fun_head_end_group = inner_rules.next().unwrap().as_str().to_string();
-                println!("fun_head_end_group:{:?}", fun_head_end_group);
                 let fun_for_content = inner_rules.next().unwrap().as_str().to_string();
-                println!("fun_for_content:{:?}", fun_for_content);
                 return Some(FunContent {
                     fun_name: fun_name_group,
                     fun_param: fun_brackets_group,
@@ -50,7 +44,6 @@ pub fn read_this_parset(unparsed_file: String) -> Option<FunContent> {
     return None;
 }
 
-
 pub fn impl_aop(_attr: &TokenStream, _input: &TokenStream) -> TokenStream {
     let attr_str = _attr.clone().to_string();
     let input_str = _input.clone().to_string();
@@ -82,7 +75,6 @@ pub fn impl_aop(_attr: &TokenStream, _input: &TokenStream) -> TokenStream {
                 celler_fun.fun_head_end_group,
                 fun_for_content
             );
-            println!("fun_head_end_group:{:?}", celler_fun.fun_head_end_group);
             let first_set_param_str =
                 format!("let mut aop_param_vec = Vec::<Box<dyn Any>>::new();");
             let last_set_param_str = format!("let mut aop_last_param_vec = Vec::<Box<dyn Any>>::new();aop_last_param_vec.push(Box::new(aop_result.clone()));");
@@ -116,7 +108,6 @@ pub fn impl_aop(_attr: &TokenStream, _input: &TokenStream) -> TokenStream {
                 );
             }
 
-            println!("aop_first_str:{:?}", aop_first_str);
             let run_source_code_str = format!(
                 "let aop_result = aop_{}({});",
                 celler_fun.fun_name, aop_set_param_str
@@ -131,7 +122,6 @@ pub fn impl_aop(_attr: &TokenStream, _input: &TokenStream) -> TokenStream {
                     "Box<(dyn Fn(Vec<Box<(dyn Any)>>) + Send + Sync )>"
                 );
             }
-            println!("aop_last_str:{:?}", aop_last_str);
             let content_concat_str = format!(
                 "{}{}{}{}{}",
                 first_set_param_str,
@@ -148,10 +138,8 @@ pub fn impl_aop(_attr: &TokenStream, _input: &TokenStream) -> TokenStream {
                 content_concat_str,
                 source_code_str
             );
-
-            println!("rs_code_str:{:?}", code_str);
+            println!("aop_code:\n{}", code_str);
             let result_token_stream = proc_macro2::TokenStream::from_str(&code_str).unwrap();
-
             return TokenStream::from(result_token_stream);
         }
         None => {
