@@ -1,113 +1,8 @@
-use std::{env, path::Path};
-
-use crate::com::toml_read;
-
-const SYMBOL_STR: &str = "/";
-
-pub fn get_path_symbol() -> String {
-    String::from(SYMBOL_STR)
-}
-
-pub fn path_sym_cast(path_str: &str, sym: &str) -> String {
-    path_str.replace("\\", sym).replace("/", sym)
-}
-
-
-
-pub  fn get_work_path()->String{
-    let sym = get_path_symbol();
-    let mut config_path = String::new();
-    let config_path_rs = env::current_dir();
-    match config_path_rs {
-        Ok(r) => {
-            if let Some(s) = r.to_str() {
-                config_path = path_sym_cast(s, &sym);
-            }
-        }
-        Err(e) => {
-            panic!("error:{:?}", e);
-        }
-    }
-    return config_path;
-}
-
-/// 
-/// 获取调用宏的项目路径
-pub fn get_caller_path()->String{
-    let sym = get_path_symbol();
-    let call_site_span = proc_macro::Span::call_site();
-    let ast_path ;
-    let sym_src = sym.clone()+"src";
-    let src_sym = "src".to_string()+&sym;
-    
-    let call_path = path_sym_cast(call_site_span
-        .source_file()
-        .path()
-        .to_str()
-        .unwrap_or(""),&sym);
-        println!("call_path:{:?}",call_path);
-        println!("call_path:{:?}",call_path.contains("src"));
-    if call_path.contains("src") {
-        let work_path = get_work_path();
-        if let None = work_path.rfind(&sym){
-            return String::new();
-        }
-        println!("test work_path:{}",work_path);
-        let work_dir_name = work_path.split_at(work_path.rfind(&sym).unwrap()).1.to_string();
-        let call_dir_name;
-        match call_path.find(&sym_src){
-            Some(r)=>{
-                call_dir_name = call_path.split_at(r).0.to_string();
-            }
-            None=>{
-                if call_path.starts_with(&src_sym){
-                    call_dir_name = work_dir_name.clone();
-                }else{
-                    return String::new();
-                }
-            }
-        }
-    
-        if !work_dir_name.eq(&call_dir_name){
-            ast_path = work_path+&sym + &call_dir_name;
-        }else{
-            ast_path = get_work_path();
-        }
-    }else{
-        
-        let call_ast_path = path_sym_cast(&call_path, &sym);
-        ast_path =  for_substring!(call_ast_path,0,call_ast_path.rfind(&sym_src).unwrap_or(call_ast_path.len())).to_string();
-    }
-    return ast_path;
-}
-
-pub fn get_caller_file_path()->String{
-    let sym = get_path_symbol();
-    let call_site_span = proc_macro::Span::call_site();
-    
-    let call_path = path_sym_cast(call_site_span
-        .source_file()
-        .path()
-        .to_str()
-        .unwrap_or(""),&sym);
-        println!("call_path:{:?}",call_path);
-    let work_path = get_work_path();
-    if call_path.starts_with("src/"){
-        return work_path.clone()+"/"+&call_path;
-    }
-    let first_str = for_substring!(call_path,0,call_path.find("/src").unwrap_or(0));
-    let last_str = for_substring!(call_path,call_path.find("/src").unwrap_or(0),call_path.len());
-    let crate_name = for_substring!(first_str,first_str.rfind(&sym).unwrap_or(0),first_str.len());
-    if let Some(_) = work_path.strip_suffix(crate_name){
-        return work_path.clone()+"/"+&call_path;
-    }
-    println!("first_str:{}",first_str);
-    println!("last_str:{}",last_str);
-    println!("crate_name:{}",crate_name);
-    return call_path;
-}
+use std::{collections::HashMap, path::Path};
 
+use crate::com::{path_utils, toml_read};
 
+use super::path_utils::{get_path_symbol, path_sym_cast};
 
 /// 读取文件夹指定后缀文件
 pub fn read_dir_file(path_vec: Vec<String>, suffix_vec: Vec<&str>) -> Vec<String> {
@@ -180,14 +75,11 @@ pub fn read_path_all_dir(
     }
 }
 
-
 //获取有效的文件夹
 pub fn get_effective_dir(path_list: &str, exclut_path: &str, lib_path: &str) -> Vec<String> {
     let mut all_dir_path_ls = Vec::new();
     //引用包实际目录
-    println!("path_list:{:?}", path_list);
     let act_path_vec = lib_path_link(path_list, lib_path);
-    println!("act_path_vec:{:?}", act_path_vec);
     //排除包实际目录
     let mut act_exclude_path_concat_str = String::new();
     if !exclut_path.is_empty() {
@@ -213,8 +105,6 @@ pub fn get_effective_dir(path_list: &str, exclut_path: &str, lib_path: &str) ->
     all_dir_path_ls
 }
 
-
-
 ///set_lib_path = 实际包地址 env!("CARGO_MANIFEST_DIR")
 /// set_lib_path = 调用宏实际包地址
 pub fn lib_path_link(path_list: &str, set_lib_path: &str) -> Vec<String> {
@@ -232,10 +122,8 @@ pub fn lib_path_link(path_list: &str, set_lib_path: &str) -> Vec<String> {
         lib_config_path.len()
     )
     .to_string();
-    println!("current_lib_name:{:?}", current_lib_name);
     let current_lib_path = "../".to_string() + &current_lib_name;
     toml_ver_map.insert(current_lib_name.clone(), (current_lib_path.clone(), true));
-    println!("toml_ver_map:{:?}", toml_ver_map);
     let check_lib_path = path_list.replace("::", &sym).clone();
     let lib_path_split = check_lib_path.split(",");
     let mut path_parent_list: Vec<String> = vec![];
@@ -243,7 +131,6 @@ pub fn lib_path_link(path_list: &str, set_lib_path: &str) -> Vec<String> {
         if path_str.is_empty() {
             continue;
         }
-        println!("path_str:{:?}", path_str);
         let mut frist_mod_path;
         let the_path_str = path_str.replace("::", &sym).replace(&up_sym, "");
         let last_mod_path = for_substring!(
@@ -252,18 +139,13 @@ pub fn lib_path_link(path_list: &str, set_lib_path: &str) -> Vec<String> {
             the_path_str.len()
         )
         .to_string();
-        println!("last_mod_path:{:?}", last_mod_path);
-        println!("the_path_str:{:?}", the_path_str);
         let lib_name = the_path_str.clone().split(&sym).collect::<Vec<&str>>()[0].to_string();
-        println!("lib_name:{:?}", lib_name);
         //是否引用依赖
         let lib_attr_opt = toml_ver_map.get(&lib_name);
         //实际地址
         match lib_attr_opt {
             Some(val) => {
-                println!("val:{:?}", val);
                 if val.1 {
-                    println!("lib_config_path:{:?}", lib_config_path);
                     frist_mod_path = get_jump_folder(
                         &lib_config_path,
                         &sym,
@@ -271,17 +153,15 @@ pub fn lib_path_link(path_list: &str, set_lib_path: &str) -> Vec<String> {
                     ) + &sym
                         + &val.0.replace("../", "");
                 } else {
-                    frist_mod_path = get_jump_folder(&lib_config_path, &sym, 1)+ &sym
-                        + &lib_name.replace("_", "-")
-                        + "-"
-                        + &val.0;
+                    let lib_crate_path = path_utils::get_lib_crate_path();
+                    frist_mod_path =
+                        lib_crate_path + &sym + &lib_name.replace("_", "-") + "-" + &val.0;
                 }
             }
             None => {
                 continue;
             }
         }
-        println!("frist_mod_path:{:?}", frist_mod_path);
         if Path::new(&(frist_mod_path.clone() + &sym + "src")).exists() {
             let frist_src = frist_mod_path.clone() + &(sym.clone() + "src");
             if Path::new(&(frist_src.clone() + &sym + &last_mod_path)).exists() {
@@ -289,7 +169,6 @@ pub fn lib_path_link(path_list: &str, set_lib_path: &str) -> Vec<String> {
             }
         }
         let result_path = frist_mod_path + &sym + &last_mod_path;
-        println!("result_path:{:?}", result_path);
         path_parent_list.push(result_path);
     }
     return path_parent_list;
@@ -301,9 +180,7 @@ pub fn lib_path_link(path_list: &str, set_lib_path: &str) -> Vec<String> {
 pub fn path_lib_link(path_list: &str, set_lib_path: &str, work_lib_path: &str) -> Vec<String> {
     let sym = get_path_symbol();
     let lib_config_path = path_sym_cast(set_lib_path, &sym);
-    //C:\\Users\\45022\\.cargo\\registry\\src\\github.com-1ecc6299db9ec823\\extends-rs-0.1.6
     //读取工作目录依赖文件信息 找到对应版本依赖文件扫描读取
-
     let toml_path = lib_config_path.clone() + &sym + "Cargo.toml";
     let mut toml_ver_map = toml_read::read_path_toml_lib_ver(&toml_path);
     let current_lib_name = for_substring!(
@@ -314,7 +191,6 @@ pub fn path_lib_link(path_list: &str, set_lib_path: &str, work_lib_path: &str) -
     .to_string();
     let current_lib_path = "../".to_string() + &current_lib_name;
     toml_ver_map.insert(current_lib_name.clone(), (current_lib_path.clone(), true));
-    println!("toml_ver_map:{:?}", toml_ver_map);
     //let check_lib_path = path_list.replace(&sym, "::").clone();
     let lib_path_split = path_list.clone().split(",");
     let mut path_parent_list: Vec<String> = vec![];
@@ -322,7 +198,6 @@ pub fn path_lib_link(path_list: &str, set_lib_path: &str, work_lib_path: &str) -
         if path_str.is_empty() {
             continue;
         }
-        println!("path_str:{:?}", path_str);
         let mut the_path_str = String::new();
         //如果有后缀 去掉
         if let Some(r) = path_str.rfind(".") {
@@ -339,16 +214,13 @@ pub fn path_lib_link(path_list: &str, set_lib_path: &str, work_lib_path: &str) -
             .split(&sym)
             .map(|f| f.to_string())
             .collect::<Vec<String>>();
-        println!("jump_dir_vec:{:?}", jump_dir_vec);
         let mut crate_path_str = String::new();
         let mut jump_record_str = the_path_str.clone();
         let max_idx = jump_dir_vec.len() - 1;
         for x in 0..max_idx {
             let jump = jump_dir_vec[max_idx - x].clone();
             crate_path_str = jump.clone() + "::" + &crate_path_str;
-            println!("crate_path_str+=:{:?}", crate_path_str);
             jump_record_str = get_jump_folder(&jump_record_str, &sym, 1);
-            println!("jump_record_str+=:{:?}", jump_record_str);
             if Path::new(&(jump_record_str.clone() + &sym + "Cargo.toml")).exists() {
                 let crate_dir_name;
                 match jump_record_str.rfind(&sym) {
@@ -368,8 +240,6 @@ pub fn path_lib_link(path_list: &str, set_lib_path: &str, work_lib_path: &str) -
         crate_path_str = for_substring!(crate_path_str, 0, crate_path_str.rfind("::").unwrap())
             .replace("src::", "");
 
-        println!("crate_path_str:{:?}", &crate_path_str);
-
         let crate_name =
             for_substring!(crate_path_str, 0, crate_path_str.find("::").unwrap()).to_string();
         if crate_name.contains("-") {
@@ -397,8 +267,6 @@ pub fn path_lib_link(path_list: &str, set_lib_path: &str, work_lib_path: &str) -
             work_lib_path.len()
         )
         .replace(&sym, "");
-        println!("work_dir_name:{:?}", work_dir_name);
-        println!("crate_name:{:?}", crate_name);
         //包与工作目录一致修改为crate
         if work_dir_name.eq(&crate_name) {
             crate_path_str = crate_path_str.replace(&crate_name, "crate");
@@ -414,7 +282,6 @@ pub fn path_lib_link(path_list: &str, set_lib_path: &str, work_lib_path: &str) -
             )
             .to_string();
         }
-        println!("crate_path_str rest:{:?}", crate_path_str);
         path_parent_list.push(crate_path_str);
     }
     return path_parent_list;
@@ -445,3 +312,40 @@ pub fn get_jump_folder(path_str_the: &str, lev_str: &str, set_lev_size: usize) -
     }
     path_str_result
 }
+
+//分解宏属性为map
+pub fn attr_split_to_map(attr_str: &str) -> HashMap<String, String> {
+    attr_str
+        .replace("/", "")
+        .replace('\n', "")
+        .replace('\\', "")
+        .trim()
+        .to_string();
+    let attr_split = attr_str.split("\",").map(|s| s.replace("\"", ""));
+    let mut attr_map = HashMap::<String, String>::new();
+    for attr_mate in attr_split {
+        let attr_sp = attr_mate.split_once("=");
+        if let Some((key, val)) = attr_sp {
+            attr_map.insert(key.trim().to_string(), val.trim().to_string());
+        }
+    }
+    return attr_map;
+}
+
+pub fn param_attr_split_to_map(attr_str: &str) -> HashMap<String, String> {
+    attr_str
+        .replace("/", "")
+        .replace('\n', "")
+        .replace('\\', "")
+        .trim()
+        .to_string();
+    let attr_split = attr_str.split(",");
+    let mut attr_map = HashMap::<String, String>::new();
+    for attr_mate in attr_split {
+        let attr_sp = attr_mate.split_once(":");
+        if let Some((key, val)) = attr_sp {
+            attr_map.insert(key.trim().to_string(), val.trim().to_string());
+        }
+    }
+    return attr_map;
+}
