@@ -11,6 +11,7 @@ extern crate pest;
 extern crate quote;
 #[macro_use]
 extern crate pest_derive;
+extern crate autopath;
 use proc_macro::TokenStream;
 mod com;
 use com::component_scan;
@@ -98,10 +99,8 @@ pub fn bean(_attr: TokenStream, _input: TokenStream) -> TokenStream {
 
 #[proc_macro_attribute]
 pub fn component_scan(_attr: TokenStream, _input: TokenStream) -> TokenStream {
-    let  ast_path = scan_path_utils::get_caller_path();
-    let work_path = scan_path_utils::get_work_path();
-    println!("ast_path:{:?}",ast_path);
-    println!("work_path:{:?}",work_path);
+    let  ast_path = path_utils::get_caller_path();
+    println!("ast_path:{}",ast_path);
     if ast_path.is_empty(){
         return _input;
     }
@@ -116,9 +115,8 @@ pub fn aop(_attr: TokenStream, _input: TokenStream) -> TokenStream {
 
 #[proc_macro_attribute]
 pub fn starter_scan(_attr: TokenStream, _input: TokenStream) -> TokenStream {
-    let  ast_path = scan_path_utils::get_caller_path();
-    println!("starter_scan ast_path:{:?}",ast_path);
-    path_utils::get_auto_starter_path();
+    let  ast_path = path_utils::get_caller_path();
+    println!("ast_path:{}",ast_path);
     return com::starter_scan::impl_starter_scan(&_attr,&_input,&ast_path);
 }
 
